==> realestate-supervise-common-1.1.0-20251204.013828-71-sources.jar: cn/gtmap/realestate/supervise/model/Respond.java <==
package cn.gtmap.realestate.supervise.model;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import java.io.Serializable;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0, 2017/8/2
 * @description 生成的标准xml响应报文
 */

@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
public class Respond implements Serializable {

    //是否成功
    @XmlElement
    private String SuccessFlag;

    @XmlElement
    private String CertID;

    //实例编号
    @XmlElement
    private String BizMsgID;

    @XmlElement
    private String AdditionalData2;

    @XmlElement
    private String AdditionalData;

    @XmlElement
    private String QRCode;

    @XmlElement
    private String ResponseInfo;

    @XmlElement
    private String ResponseCode;

    //消息服务端名称
    @XmlElement
    private String serverName;

    //监管标识码
    @XmlElement
    private String JGBSF;

    //报文ID
    @XmlElement
    private String BWID;

    //上级失败标记
    private String sbsbbj;

    private String fileName;

    private String areaCode;

    public Respond() {
    }

    public String getSuccessFlag() {
        return SuccessFlag;
    }

    public void setSuccessFlag(String successFlag) {
        SuccessFlag = successFlag;
    }

    public String getCertID() {
        return CertID;
    }

    public void setCertID(String certID) {
        CertID = certID;
    }

    public String getBizMsgID() {
        return BizMsgID;
    }

    public void setBizMsgID(String bizMsgID) {
        BizMsgID = bizMsgID;
    }

    public String getAdditionalData2() {
        return AdditionalData2;
    }

    public void setAdditionalData2(String additionalData2) {
        AdditionalData2 = additionalData2;
    }

    public String getAdditionalData() {
        return AdditionalData;
    }

    public void setAdditionalData(String additionalData) {
        AdditionalData = additionalData;
    }

    public String getQRCode() {
        return QRCode;
    }

    public void setQRCode(String QRCode) {
        this.QRCode = QRCode;
    }

    public String getResponseInfo() {
        return ResponseInfo;
    }

    public void setResponseInfo(String responseInfo) {
        ResponseInfo = responseInfo;
    }

    public String getResponseCode() {
        return ResponseCode;
    }

    public void setResponseCode(String responseCode) {
        ResponseCode = responseCode;
    }

    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }

    public String getAreaCode() {
        return areaCode;
    }

    public void setAreaCode(String areaCode) {
        this.areaCode = areaCode;
    }

    public String getServerName() {
        return serverName;
    }

    public void setServerName(String serverName) {
        this.serverName = serverName;
    }

    public String getSbsbbj() {
        return sbsbbj;
    }

    public void setSbsbbj(String sbsbbj) {
        this.sbsbbj = sbsbbj;
    }

    public String getJGBSF() {
        return JGBSF;
    }

    public void setJGBSF(String JGBSF) {
        this.JGBSF = JGBSF;
    }

    public String getBWID() {
        return BWID;
    }

    public void setBWID(String BWID) {
        this.BWID = BWID;
    }
}

==> realestate-supervise-common-1.1.0-20251208.011103-73-sources.jar: cn/gtmap/realestate/supervise/model/Respond.java <==
package cn.gtmap.realestate.supervise.model;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import java.io.Serializable;
import java.util.List;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0, 2017/8/2
 * @description 生成的标准xml响应报文
 */

@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
public class Respond implements Serializable {

    //是否成功
    @XmlElement
    private String SuccessFlag;

    @XmlElement
    private String CertID;

    //实例编号
    @XmlElement
    private String BizMsgID;

    @XmlElement
    private String AdditionalData2;

    @XmlElement
    private String AdditionalData;

    @XmlElement
    private String QRCode;

    @XmlElement
    private String ResponseInfo;

    @XmlElement
    private String ResponseCode;

    //消息服务端名称
    @XmlElement
    private String serverName;

    //监管标识码
    @XmlElement
    private String JGBSF;

    //报文ID
    @XmlElement
    private String BWID;

    @XmlElement(name = "Data")
    private Data data;

    @XmlAccessorType(XmlAccessType.FIELD)
    public static class Data {
        @XmlElement(name = "ZJJGMXLIST")
        private List<Zjjgmx> zjjgmxList;

        public List<Zjjgmx> getZjjgmxList() {
            return zjjgmxList;
        }

        public void setZjjgmxList(List<Zjjgmx> zjjgmxList) {
            this.zjjgmxList = zjjgmxList;
        }
    }

    //上级失败标记
    private String sbsbbj;

    private String fileName;

    private String areaCode;

    public Respond() {
    }

    public String getSuccessFlag() {
        return SuccessFlag;
    }

    public void setSuccessFlag(String successFlag) {
        SuccessFlag = successFlag;
    }

    public String getCertID() {
        return CertID;
    }

    public void setCertID(String certID) {
        CertID = certID;
    }

    public String getBizMsgID() {
        return BizMsgID;
    }

    public void setBizMsgID(String bizMsgID) {
        BizMsgID = bizMsgID;
    }

    public String getAdditionalData2() {
        return AdditionalData2;
    }

    public void setAdditionalData2(String additionalData2) {
        AdditionalData2 = additionalData2;
    }

    public String getAdditionalData() {
        return AdditionalData;
    }

    public void setAdditionalData(String additionalData) {
        AdditionalData = additionalData;
    }

    public String getQRCode() {
        return QRCode;
    }

    public void setQRCode(String QRCode) {
        this.QRCode = QRCode;
    }

    public String getResponseInfo() {
        return ResponseInfo;
    }

    public void setResponseInfo(String responseInfo) {
        ResponseInfo = responseInfo;
    }

    public String getResponseCode() {
        return ResponseCode;
    }

    public void setResponseCode(String responseCode) {
        ResponseCode = responseCode;
    }

    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }

    public String getAreaCode() {
        return areaCode;
    }

    public void setAreaCode(String areaCode) {
        this.areaCode = areaCode;
    }

    public String getServerName() {
        return serverName;
    }

    public void setServerName(String serverName) {
        this.serverName = serverName;
    }

    public String getSbsbbj() {
        return sbsbbj;
    }

    public void setSbsbbj(String sbsbbj) {
        this.sbsbbj = sbsbbj;
    }

    public String getJGBSF() {
        return JGBSF;
    }

    public void setJGBSF(String JGBSF) {
        this.JGBSF = JGBSF;
    }

    public String getBWID() {
        return BWID;
    }

    public void setBWID(String BWID) {
        this.BWID = BWID;
    }

    public Data getData() {
        return data;
    }

    public void setData(Data data) {
        this.data = data;
    }
}
